# BillingAccountPaymentMethod

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**card** | [**PaymentMethodCard**](PaymentMethodCard.md) |  | [optional] 
**id** | **str** |  | [optional] 
**is_default** | **bool** |  | [optional] 
**paypal** | [**PaymentMethodPaypal**](PaymentMethodPaypal.md) |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


